package resolvers

import (
	"context"
	"fmt"
	"github.com/authorizerdev/authorizer/server/db"
	"github.com/authorizerdev/authorizer/server/graph/model"
	"github.com/authorizerdev/authorizer/server/refs"
	log "github.com/sirupsen/logrus"
	"strings"
)

// IsRegisteredResolver is a resolver for registered checkup query
func IsRegisteredResolver(ctx context.Context, email string) (*model.AuthResponse, error) {
	var res *model.AuthResponse
	email = strings.TrimSpace(refs.StringValue(&email))
	if email == "" {
		log.Debug("Email is required")
		return res, fmt.Errorf(`email is required`)
	}

	log := log.WithField("email", email)

	// find user with email
	existingUser, err := db.Provider.GetUserByEmail(ctx, email)
	if err != nil {
		log.Debug("Failed to get user by email: ", err)
	}

	if existingUser != nil {
		res.Message = "registered"
		if existingUser.EmailVerifiedAt != nil {
			res.Message = "verified"
			log.Debug("Email is already verified and signed up.")
			return res, fmt.Errorf(`%s has already signed up`, email)
		} else if existingUser.ID != "" && existingUser.EmailVerifiedAt == nil {
			res.Message = "not verified"
			log.Debug("Email is already signed up. Verification pending...")
			return res, fmt.Errorf("%s has already signed up. please complete the email verification process or reset the password", email)
		}
	}

	return res, nil
}
